# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/listener/v1/listener.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/app/listener/v1/listener.proto\x12\x18\x62ilibili.app.listener.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"o\n\x06\x41uthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\x12:\n\x08relation\x18\x04 \x01(\x0b\x32(.bilibili.app.listener.v1.FollowRelation\"\x88\x01\n\x0f\x42KArcDetailsReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x42\n\nplayerArgs\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"F\n\x10\x42KArcDetailsResp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"\xe4\x01\n\tBKArchive\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\x0b\n\x03rid\x18\x06 \x01(\x05\x12\r\n\x05rname\x18\x07 \x01(\t\x12\x0f\n\x07publish\x18\x08 \x01(\x03\x12\x15\n\rdisplayed_oid\x18\t \x01(\t\x12\x11\n\tcopyright\x18\n \x01(\x05\x12\x35\n\x06rights\x18\x0b \x01(\x0b\x32%.bilibili.app.listener.v1.BKArcRights\"W\n\tBKArcPart\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0e\n\x06sub_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x0c\n\x04page\x18\x05 \x01(\x05\"!\n\x0b\x42KArcRights\x12\x12\n\nno_reprint\x18\x01 \x01(\x05\"\x98\x01\n\x06\x42KStat\x12\x0c\n\x04like\x18\x01 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x02 \x01(\x05\x12\x11\n\tfavourite\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\r\n\x05share\x18\x05 \x01(\x05\x12\x0c\n\x04view\x18\x06 \x01(\x05\x12\x10\n\x08has_like\x18\x07 \x01(\x08\x12\x10\n\x08has_coin\x18\x08 \x01(\x08\x12\x0f\n\x07has_fav\x18\t \x01(\x08\"\xee\x01\n\nCardModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\x05\x12=\n\rmodule_header\x18\x02 \x01(\x0b\x32$.bilibili.app.listener.v1.PkcmHeaderH\x00\x12?\n\x0emodule_archive\x18\x03 \x01(\x0b\x32%.bilibili.app.listener.v1.PkcmArchiveH\x00\x12\x41\n\x0bmodule_cbtn\x18\x04 \x01(\x0b\x32*.bilibili.app.listener.v1.PkcmCenterButtonH\x00\x42\x08\n\x06module\"]\n\nCoinAddReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12\x10\n\x08thumb_up\x18\x03 \x01(\x08\"\x1e\n\x0b\x43oinAddResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xdf\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\x05\x12\x11\n\tmime_type\x18\x05 \x01(\t\x12\x0e\n\x06\x63odecs\x18\x06 \x01(\t\x12?\n\x0csegment_base\x18\x0c \x01(\x0b\x32).bilibili.app.listener.v1.DashSegmentBase\x12\x0f\n\x07\x63odecid\x18\r \x01(\x05\x12\x0b\n\x03md5\x18\x0e \x01(\t\x12\x0c\n\x04size\x18\x0f \x01(\x03\">\n\x0f\x44\x61shSegmentBase\x12\x16\n\x0einitialization\x18\x01 \x01(\t\x12\x13\n\x0bindex_range\x18\x02 \x01(\t\"\xef\x03\n\nDetailItem\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x30\n\x03\x61rc\x18\x02 \x01(\x0b\x32#.bilibili.app.listener.v1.BKArchive\x12\x32\n\x05parts\x18\x03 \x03(\x0b\x32#.bilibili.app.listener.v1.BKArcPart\x12/\n\x05owner\x18\x04 \x01(\x0b\x32 .bilibili.app.listener.v1.Author\x12.\n\x04stat\x18\x05 \x01(\x0b\x32 .bilibili.app.listener.v1.BKStat\x12\x11\n\tlast_part\x18\x06 \x01(\x03\x12\x10\n\x08progress\x18\x07 \x01(\x03\x12\x10\n\x08playable\x18\x08 \x01(\x05\x12\x0f\n\x07message\x18\t \x01(\t\x12I\n\x0bplayer_info\x18\n \x03(\x0b\x32\x34.bilibili.app.listener.v1.DetailItem.PlayerInfoEntry\x1aU\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayInfo:\x02\x38\x01\"j\n\rEventTracking\x12\x10\n\x08operator\x18\x01 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x02 \x01(\t\x12\x10\n\x08track_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_type\x18\x04 \x01(\t\x12\x11\n\tentity_id\x18\x05 \x01(\t\"\xf4\x02\n\tFavFolder\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x38\n\x05owner\x18\x03 \x01(\x0b\x32).bilibili.app.listener.v1.FavFolderAuthor\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x06 \x01(\t\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x0c\n\x04\x61ttr\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\x05\x12\x0f\n\x07\x66\x61vored\x18\n \x01(\x05\x12\r\n\x05\x63time\x18\x0b \x01(\x03\x12\r\n\x05mtime\x18\x0c \x01(\x03\x12\x14\n\x0cstat_fav_cnt\x18\r \x01(\x05\x12\x16\n\x0estat_share_cnt\x18\x0e \x01(\x05\x12\x15\n\rstat_like_cnt\x18\x0f \x01(\x05\x12\x15\n\rstat_Play_cnt\x18\x10 \x01(\x05\x12\x16\n\x0estat_reply_cnt\x18\x11 \x01(\x05\x12\x11\n\tfav_state\x18\x12 \x01(\x05\"C\n\x0f\x46\x61vFolderAction\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x05\",\n\x0f\x46\x61vFolderAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x12\x46\x61vFolderCreateReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0e\n\x06public\x18\x03 \x01(\x05\x12\x13\n\x0b\x66older_type\x18\x04 \x01(\x05\"H\n\x13\x46\x61vFolderCreateResp\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x12\x46\x61vFolderDeleteReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\"&\n\x13\x46\x61vFolderDeleteResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xaa\x01\n\x12\x46\x61vFolderDetailReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x0f\n\x07\x66\x61v_mid\x18\x03 \x01(\x03\x12\x34\n\tlast_item\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItem\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x18\n\x10need_folder_info\x18\x06 \x01(\x08\"\xa8\x01\n\x13\x46\x61vFolderDetailResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x11\n\treach_end\x18\x02 \x01(\x08\x12\x35\n\x04list\x18\x03 \x03(\x0b\x32\'.bilibili.app.listener.v1.FavItemDetail\x12\x38\n\x0b\x66older_info\x18\x04 \x01(\x0b\x32#.bilibili.app.listener.v1.FavFolder\"Z\n\x10\x46\x61vFolderListReq\x12\x14\n\x0c\x66older_types\x18\x01 \x03(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"F\n\x11\x46\x61vFolderListResp\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.bilibili.app.listener.v1.FavFolder\"1\n\rFavFolderMeta\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\"\x96\x01\n\x07\x46\x61vItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03\x66id\x18\x03 \x01(\x03\x12\x0b\n\x03mid\x18\x04 \x01(\x03\x12\r\n\x05mtime\x18\x05 \x01(\x03\x12\r\n\x05\x63time\x18\x06 \x01(\x03\x12\x33\n\x02\x65t\x18\x07 \x01(\x0b\x32\'.bilibili.app.listener.v1.EventTracking\"\x9f\x01\n\rFavItemAddReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x32\n\x04play\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"!\n\x0e\x46\x61vItemAddResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"*\n\rFavItemAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xbb\x01\n\x0f\x46\x61vItemBatchReq\x12:\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32).bilibili.app.listener.v1.FavFolderAction\x12\x32\n\x04play\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x03 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"#\n\x10\x46\x61vItemBatchResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x9f\x01\n\rFavItemDelReq\x12\x0b\n\x03\x66id\x18\x01 \x01(\x03\x12\x13\n\x0b\x66older_type\x18\x02 \x01(\x05\x12\x32\n\x04play\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x30\n\x03\x66\x61v\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItemH\x00\x42\x06\n\x04item\"!\n\x0e\x46\x61vItemDelResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x8b\x02\n\rFavItemDetail\x12/\n\x04item\x18\x01 \x01(\x0b\x32!.bilibili.app.listener.v1.FavItem\x12\x36\n\x05owner\x18\x02 \x01(\x0b\x32\'.bilibili.app.listener.v1.FavItemAuthor\x12\x33\n\x04stat\x18\x03 \x01(\x0b\x32%.bilibili.app.listener.v1.FavItemStat\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\r\n\x05parts\x18\t \x01(\x05\"*\n\x0b\x46\x61vItemStat\x12\x0c\n\x04view\x18\x01 \x01(\x05\x12\r\n\x05reply\x18\x02 \x01(\x05\"`\n\x16\x46\x61voredInAnyFoldersReq\x12\x14\n\x0c\x66older_types\x18\x01 \x03(\x05\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x85\x01\n\x17\x46\x61voredInAnyFoldersResp\x12\x38\n\x07\x66olders\x18\x01 \x03(\x0b\x32\'.bilibili.app.listener.v1.FavFolderMeta\x12\x30\n\x04item\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\" \n\x0e\x46ollowRelation\x12\x0e\n\x06status\x18\x01 \x01(\x05\"t\n\x11\x46ormatDescription\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x04 \x01(\t\x12\x13\n\x0bsuperscript\x18\x05 \x01(\t\"i\n\nPageOption\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x11\n\tdirection\x18\x02 \x01(\x05\x12\x35\n\tlast_item\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"\x81\x02\n\x0bPickArchive\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\r\n\x05title\x18\x02 \x01(\t\x12:\n\x05owner\x18\x03 \x01(\x0b\x32+.bilibili.app.listener.v1.PickArchiveAuthor\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\r\n\x05parts\x18\x06 \x01(\x05\x12\x11\n\tstat_view\x18\x07 \x01(\x05\x12\x12\n\nstat_reply\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\x05\x12\x0f\n\x07message\x18\n \x01(\t\".\n\x11PickArchiveAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x08PickCard\x12\x0f\n\x07pick_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63\x61rd_id\x18\x02 \x01(\x03\x12\x11\n\tcard_name\x18\x03 \x01(\t\x12\x35\n\x07modules\x18\x04 \x03(\x0b\x32$.bilibili.app.listener.v1.CardModule\"5\n\x11PickCardDetailReq\x12\x0f\n\x07\x63\x61rd_id\x18\x01 \x01(\x03\x12\x0f\n\x07pick_id\x18\x02 \x01(\x03\"m\n\x12PickCardDetailResp\x12\x0f\n\x07\x63\x61rd_id\x18\x01 \x01(\x03\x12\x0f\n\x07pick_id\x18\x02 \x01(\x03\x12\x35\n\x07modules\x18\x03 \x03(\x0b\x32$.bilibili.app.listener.v1.CardModule\"\x1d\n\x0bPickFeedReq\x12\x0e\n\x06offset\x18\x01 \x01(\x03\"Q\n\x0cPickFeedResp\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x31\n\x05\x63\x61rds\x18\x02 \x03(\x0b\x32\".bilibili.app.listener.v1.PickCard\"V\n\x0bPkcmArchive\x12\x32\n\x03\x61rc\x18\x01 \x01(\x0b\x32%.bilibili.app.listener.v1.PickArchive\x12\x13\n\x0bpick_reason\x18\x02 \x01(\t\"T\n\x10PkcmCenterButton\x12\x11\n\ticon_head\x18\x01 \x01(\t\x12\x11\n\ticon_tail\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"^\n\nPkcmHeader\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08\x62tn_icon\x18\x03 \x01(\t\x12\x10\n\x08\x62tn_text\x18\x04 \x01(\t\x12\x0f\n\x07\x62tn_uri\x18\x05 \x01(\t\"G\n\x13PlayActionReportReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"h\n\x08PlayDASH\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x12\x17\n\x0fmin_buffer_time\x18\x02 \x01(\x02\x12\x31\n\x05\x61udio\x18\x03 \x03(\x0b\x32\".bilibili.app.listener.v1.DashItem\"}\n\x11PlayHistoryAddReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x12\n\nplay_style\x18\x04 \x01(\x05\"X\n\x11PlayHistoryDelReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08truncate\x18\x02 \x01(\x08\"H\n\x0ePlayHistoryReq\x12\x36\n\x08page_opt\x18\x01 \x01(\x0b\x32$.bilibili.app.listener.v1.PageOption\"g\n\x0fPlayHistoryResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x11\n\treach_end\x18\x02 \x01(\x08\x12\x32\n\x04list\x18\x03 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\"\xa4\x02\n\x08PlayInfo\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x0f\n\x07qn_type\x18\x03 \x01(\x05\x12\x35\n\x08play_url\x18\x04 \x01(\x0b\x32!.bilibili.app.listener.v1.PlayURLH\x00\x12\x37\n\tplay_dash\x18\x05 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayDASHH\x00\x12\r\n\x05\x66nver\x18\x06 \x01(\x05\x12\r\n\x05\x66nval\x18\x07 \x01(\x05\x12\x0f\n\x07\x66ormats\x18\x08 \x03(\x05\x12\x15\n\rvideo_codecid\x18\t \x01(\x05\x12\x0e\n\x06length\x18\n \x01(\x03\x12\x0c\n\x04\x63ode\x18\x0b \x01(\x05\x12\x0f\n\x07message\x18\x0c \x01(\tB\x06\n\x04info\"o\n\x08PlayItem\x12\x11\n\titem_type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x0e\n\x06sub_id\x18\x04 \x03(\x03\x12\x33\n\x02\x65t\x18\x05 \x01(\x0b\x32\'.bilibili.app.listener.v1.EventTracking\"\x9f\x01\n\x0ePlaylistAddReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x33\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItemH\x00\x12\x0e\n\x04head\x18\x03 \x01(\x08H\x00\x12\x0e\n\x04tail\x18\x04 \x01(\x08H\x00\x42\x05\n\x03pos\"U\n\x0ePlaylistDelReq\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08truncate\x18\x02 \x01(\x08\"\xea\x01\n\x0bPlaylistReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x32\n\x06\x61nchor\x18\x03 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x36\n\x08page_opt\x18\x04 \x01(\x0b\x32$.bilibili.app.listener.v1.PageOption\x12\x43\n\x0bplayer_args\x18\x05 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08\x65xtra_id\x18\x06 \x01(\x03\"\xc7\x01\n\x0cPlaylistResp\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x13\n\x0breach_start\x18\x02 \x01(\x08\x12\x11\n\treach_end\x18\x03 \x01(\x08\x12\x32\n\x04list\x18\x04 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x35\n\tlast_play\x18\x05 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x15\n\rlast_progress\x18\x06 \x01(\x03\">\n\x07PlayURL\x12\x33\n\x04\x64url\x18\x01 \x03(\x0b\x32%.bilibili.app.listener.v1.ResponseUrl\"\x83\x01\n\nPlayURLReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x43\n\x0bplayer_args\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\x84\x02\n\x0bPlayURLResp\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x10\n\x08playable\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12I\n\nplayerInfo\x18\x04 \x03(\x0b\x32\x35.bilibili.app.listener.v1.PlayURLResp.PlayerInfoEntry\x1aU\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayInfo:\x02\x38\x01\"A\n\x0fRcmdPlaylistReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x14\n\x0cneed_history\x18\x03 \x01(\x08\"[\n\x10RcmdPlaylistResp\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.listener.v1.DetailItem\x12\x13\n\x0bhistory_len\x18\x02 \x01(\x03\"\x86\x01\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\r\n\x05\x61head\x18\x04 \x01(\t\x12\r\n\x05vhead\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x12\n\nbackup_url\x18\x07 \x03(\t\x12\x0b\n\x03md5\x18\x08 \x01(\t\"N\n\nThumbUpReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x05\"\x1e\n\x0bThumbUpResp\x12\x0f\n\x07message\x18\x01 \x01(\t\"A\n\rTripleLikeReq\x12\x30\n\x04item\x18\x01 \x01(\x0b\x32\".bilibili.app.listener.v1.PlayItem\"T\n\x0eTripleLikeResp\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08thumb_ok\x18\x02 \x01(\x08\x12\x0f\n\x07\x63oin_ok\x18\x03 \x01(\x08\x12\x0e\n\x06\x66\x61v_ok\x18\x04 \x01(\x08*\\\n\x0e\x43\x61rdModuleType\x12\x12\n\x0eModule_invalid\x10\x00\x12\x11\n\rModule_header\x10\x01\x12\x12\n\x0eModule_archive\x10\x02\x12\x0f\n\x0bModule_cbtn\x10\x03*\x96\x01\n\x0ePlaylistSource\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tMEM_SPACE\x10\x01\x12\x14\n\x10\x41UDIO_COLLECTION\x10\x02\x12\x0e\n\nAUDIO_CARD\x10\x03\x12\x12\n\x0eUSER_FAVOURITE\x10\x04\x12\x0e\n\nUP_ARCHIVE\x10\x05\x12\x0f\n\x0b\x41UDIO_CACHE\x10\x06\x12\r\n\tPICK_CARD\x10\x07\x32\x8a\x12\n\x08Listener\x12\x36\n\x04Ping\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12V\n\x07PlayUrl\x12$.bilibili.app.listener.v1.PlayURLReq\x1a%.bilibili.app.listener.v1.PlayURLResp\x12\x65\n\x0c\x42karcDetails\x12).bilibili.app.listener.v1.BKArcDetailsReq\x1a*.bilibili.app.listener.v1.BKArcDetailsResp\x12Y\n\x08Playlist\x12%.bilibili.app.listener.v1.PlaylistReq\x1a&.bilibili.app.listener.v1.PlaylistResp\x12O\n\x0bPlaylistAdd\x12(.bilibili.app.listener.v1.PlaylistAddReq\x1a\x16.google.protobuf.Empty\x12O\n\x0bPlaylistDel\x12(.bilibili.app.listener.v1.PlaylistDelReq\x1a\x16.google.protobuf.Empty\x12\x65\n\x0cRcmdPlaylist\x12).bilibili.app.listener.v1.RcmdPlaylistReq\x1a*.bilibili.app.listener.v1.RcmdPlaylistResp\x12\x62\n\x0bPlayHistory\x12(.bilibili.app.listener.v1.PlayHistoryReq\x1a).bilibili.app.listener.v1.PlayHistoryResp\x12U\n\x0ePlayHistoryAdd\x12+.bilibili.app.listener.v1.PlayHistoryAddReq\x1a\x16.google.protobuf.Empty\x12U\n\x0ePlayHistoryDel\x12+.bilibili.app.listener.v1.PlayHistoryDelReq\x1a\x16.google.protobuf.Empty\x12Y\n\x10PlayActionReport\x12-.bilibili.app.listener.v1.PlayActionReportReq\x1a\x16.google.protobuf.Empty\x12_\n\nTripleLike\x12\'.bilibili.app.listener.v1.TripleLikeReq\x1a(.bilibili.app.listener.v1.TripleLikeResp\x12V\n\x07ThumbUp\x12$.bilibili.app.listener.v1.ThumbUpReq\x1a%.bilibili.app.listener.v1.ThumbUpResp\x12V\n\x07\x43oinAdd\x12$.bilibili.app.listener.v1.CoinAddReq\x1a%.bilibili.app.listener.v1.CoinAddResp\x12_\n\nFavItemAdd\x12\'.bilibili.app.listener.v1.FavItemAddReq\x1a(.bilibili.app.listener.v1.FavItemAddResp\x12_\n\nFavItemDel\x12\'.bilibili.app.listener.v1.FavItemDelReq\x1a(.bilibili.app.listener.v1.FavItemDelResp\x12\x65\n\x0c\x46\x61vItemBatch\x12).bilibili.app.listener.v1.FavItemBatchReq\x1a*.bilibili.app.listener.v1.FavItemBatchResp\x12z\n\x13\x46\x61voredInAnyFolders\x12\x30.bilibili.app.listener.v1.FavoredInAnyFoldersReq\x1a\x31.bilibili.app.listener.v1.FavoredInAnyFoldersResp\x12h\n\rFavFolderList\x12*.bilibili.app.listener.v1.FavFolderListReq\x1a+.bilibili.app.listener.v1.FavFolderListResp\x12n\n\x0f\x46\x61vFolderDetail\x12,.bilibili.app.listener.v1.FavFolderDetailReq\x1a-.bilibili.app.listener.v1.FavFolderDetailResp\x12n\n\x0f\x46\x61vFolderCreate\x12,.bilibili.app.listener.v1.FavFolderCreateReq\x1a-.bilibili.app.listener.v1.FavFolderCreateResp\x12n\n\x0f\x46\x61vFolderDelete\x12,.bilibili.app.listener.v1.FavFolderDeleteReq\x1a-.bilibili.app.listener.v1.FavFolderDeleteResp\x12Y\n\x08PickFeed\x12%.bilibili.app.listener.v1.PickFeedReq\x1a&.bilibili.app.listener.v1.PickFeedResp\x12k\n\x0ePickCardDetail\x12+.bilibili.app.listener.v1.PickCardDetailReq\x1a,.bilibili.app.listener.v1.PickCardDetailRespb\x06proto3')

_CARDMODULETYPE = DESCRIPTOR.enum_types_by_name['CardModuleType']
CardModuleType = enum_type_wrapper.EnumTypeWrapper(_CARDMODULETYPE)
_PLAYLISTSOURCE = DESCRIPTOR.enum_types_by_name['PlaylistSource']
PlaylistSource = enum_type_wrapper.EnumTypeWrapper(_PLAYLISTSOURCE)
Module_invalid = 0
Module_header = 1
Module_archive = 2
Module_cbtn = 3
DEFAULT = 0
MEM_SPACE = 1
AUDIO_COLLECTION = 2
AUDIO_CARD = 3
USER_FAVOURITE = 4
UP_ARCHIVE = 5
AUDIO_CACHE = 6
PICK_CARD = 7


_AUTHOR = DESCRIPTOR.message_types_by_name['Author']
_BKARCDETAILSREQ = DESCRIPTOR.message_types_by_name['BKArcDetailsReq']
_BKARCDETAILSRESP = DESCRIPTOR.message_types_by_name['BKArcDetailsResp']
_BKARCHIVE = DESCRIPTOR.message_types_by_name['BKArchive']
_BKARCPART = DESCRIPTOR.message_types_by_name['BKArcPart']
_BKARCRIGHTS = DESCRIPTOR.message_types_by_name['BKArcRights']
_BKSTAT = DESCRIPTOR.message_types_by_name['BKStat']
_CARDMODULE = DESCRIPTOR.message_types_by_name['CardModule']
_COINADDREQ = DESCRIPTOR.message_types_by_name['CoinAddReq']
_COINADDRESP = DESCRIPTOR.message_types_by_name['CoinAddResp']
_DASHITEM = DESCRIPTOR.message_types_by_name['DashItem']
_DASHSEGMENTBASE = DESCRIPTOR.message_types_by_name['DashSegmentBase']
_DETAILITEM = DESCRIPTOR.message_types_by_name['DetailItem']
_DETAILITEM_PLAYERINFOENTRY = _DETAILITEM.nested_types_by_name['PlayerInfoEntry']
_EVENTTRACKING = DESCRIPTOR.message_types_by_name['EventTracking']
_FAVFOLDER = DESCRIPTOR.message_types_by_name['FavFolder']
_FAVFOLDERACTION = DESCRIPTOR.message_types_by_name['FavFolderAction']
_FAVFOLDERAUTHOR = DESCRIPTOR.message_types_by_name['FavFolderAuthor']
_FAVFOLDERCREATEREQ = DESCRIPTOR.message_types_by_name['FavFolderCreateReq']
_FAVFOLDERCREATERESP = DESCRIPTOR.message_types_by_name['FavFolderCreateResp']
_FAVFOLDERDELETEREQ = DESCRIPTOR.message_types_by_name['FavFolderDeleteReq']
_FAVFOLDERDELETERESP = DESCRIPTOR.message_types_by_name['FavFolderDeleteResp']
_FAVFOLDERDETAILREQ = DESCRIPTOR.message_types_by_name['FavFolderDetailReq']
_FAVFOLDERDETAILRESP = DESCRIPTOR.message_types_by_name['FavFolderDetailResp']
_FAVFOLDERLISTREQ = DESCRIPTOR.message_types_by_name['FavFolderListReq']
_FAVFOLDERLISTRESP = DESCRIPTOR.message_types_by_name['FavFolderListResp']
_FAVFOLDERMETA = DESCRIPTOR.message_types_by_name['FavFolderMeta']
_FAVITEM = DESCRIPTOR.message_types_by_name['FavItem']
_FAVITEMADDREQ = DESCRIPTOR.message_types_by_name['FavItemAddReq']
_FAVITEMADDRESP = DESCRIPTOR.message_types_by_name['FavItemAddResp']
_FAVITEMAUTHOR = DESCRIPTOR.message_types_by_name['FavItemAuthor']
_FAVITEMBATCHREQ = DESCRIPTOR.message_types_by_name['FavItemBatchReq']
_FAVITEMBATCHRESP = DESCRIPTOR.message_types_by_name['FavItemBatchResp']
_FAVITEMDELREQ = DESCRIPTOR.message_types_by_name['FavItemDelReq']
_FAVITEMDELRESP = DESCRIPTOR.message_types_by_name['FavItemDelResp']
_FAVITEMDETAIL = DESCRIPTOR.message_types_by_name['FavItemDetail']
_FAVITEMSTAT = DESCRIPTOR.message_types_by_name['FavItemStat']
_FAVOREDINANYFOLDERSREQ = DESCRIPTOR.message_types_by_name['FavoredInAnyFoldersReq']
_FAVOREDINANYFOLDERSRESP = DESCRIPTOR.message_types_by_name['FavoredInAnyFoldersResp']
_FOLLOWRELATION = DESCRIPTOR.message_types_by_name['FollowRelation']
_FORMATDESCRIPTION = DESCRIPTOR.message_types_by_name['FormatDescription']
_PAGEOPTION = DESCRIPTOR.message_types_by_name['PageOption']
_PICKARCHIVE = DESCRIPTOR.message_types_by_name['PickArchive']
_PICKARCHIVEAUTHOR = DESCRIPTOR.message_types_by_name['PickArchiveAuthor']
_PICKCARD = DESCRIPTOR.message_types_by_name['PickCard']
_PICKCARDDETAILREQ = DESCRIPTOR.message_types_by_name['PickCardDetailReq']
_PICKCARDDETAILRESP = DESCRIPTOR.message_types_by_name['PickCardDetailResp']
_PICKFEEDREQ = DESCRIPTOR.message_types_by_name['PickFeedReq']
_PICKFEEDRESP = DESCRIPTOR.message_types_by_name['PickFeedResp']
_PKCMARCHIVE = DESCRIPTOR.message_types_by_name['PkcmArchive']
_PKCMCENTERBUTTON = DESCRIPTOR.message_types_by_name['PkcmCenterButton']
_PKCMHEADER = DESCRIPTOR.message_types_by_name['PkcmHeader']
_PLAYACTIONREPORTREQ = DESCRIPTOR.message_types_by_name['PlayActionReportReq']
_PLAYDASH = DESCRIPTOR.message_types_by_name['PlayDASH']
_PLAYHISTORYADDREQ = DESCRIPTOR.message_types_by_name['PlayHistoryAddReq']
_PLAYHISTORYDELREQ = DESCRIPTOR.message_types_by_name['PlayHistoryDelReq']
_PLAYHISTORYREQ = DESCRIPTOR.message_types_by_name['PlayHistoryReq']
_PLAYHISTORYRESP = DESCRIPTOR.message_types_by_name['PlayHistoryResp']
_PLAYINFO = DESCRIPTOR.message_types_by_name['PlayInfo']
_PLAYITEM = DESCRIPTOR.message_types_by_name['PlayItem']
_PLAYLISTADDREQ = DESCRIPTOR.message_types_by_name['PlaylistAddReq']
_PLAYLISTDELREQ = DESCRIPTOR.message_types_by_name['PlaylistDelReq']
_PLAYLISTREQ = DESCRIPTOR.message_types_by_name['PlaylistReq']
_PLAYLISTRESP = DESCRIPTOR.message_types_by_name['PlaylistResp']
_PLAYURL = DESCRIPTOR.message_types_by_name['PlayURL']
_PLAYURLREQ = DESCRIPTOR.message_types_by_name['PlayURLReq']
_PLAYURLRESP = DESCRIPTOR.message_types_by_name['PlayURLResp']
_PLAYURLRESP_PLAYERINFOENTRY = _PLAYURLRESP.nested_types_by_name['PlayerInfoEntry']
_RCMDPLAYLISTREQ = DESCRIPTOR.message_types_by_name['RcmdPlaylistReq']
_RCMDPLAYLISTRESP = DESCRIPTOR.message_types_by_name['RcmdPlaylistResp']
_RESPONSEURL = DESCRIPTOR.message_types_by_name['ResponseUrl']
_THUMBUPREQ = DESCRIPTOR.message_types_by_name['ThumbUpReq']
_THUMBUPRESP = DESCRIPTOR.message_types_by_name['ThumbUpResp']
_TRIPLELIKEREQ = DESCRIPTOR.message_types_by_name['TripleLikeReq']
_TRIPLELIKERESP = DESCRIPTOR.message_types_by_name['TripleLikeResp']
Author = _reflection.GeneratedProtocolMessageType('Author', (_message.Message,), {
  'DESCRIPTOR' : _AUTHOR,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.Author)
  })
_sym_db.RegisterMessage(Author)

BKArcDetailsReq = _reflection.GeneratedProtocolMessageType('BKArcDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _BKARCDETAILSREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArcDetailsReq)
  })
_sym_db.RegisterMessage(BKArcDetailsReq)

BKArcDetailsResp = _reflection.GeneratedProtocolMessageType('BKArcDetailsResp', (_message.Message,), {
  'DESCRIPTOR' : _BKARCDETAILSRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArcDetailsResp)
  })
_sym_db.RegisterMessage(BKArcDetailsResp)

BKArchive = _reflection.GeneratedProtocolMessageType('BKArchive', (_message.Message,), {
  'DESCRIPTOR' : _BKARCHIVE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArchive)
  })
_sym_db.RegisterMessage(BKArchive)

BKArcPart = _reflection.GeneratedProtocolMessageType('BKArcPart', (_message.Message,), {
  'DESCRIPTOR' : _BKARCPART,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArcPart)
  })
_sym_db.RegisterMessage(BKArcPart)

BKArcRights = _reflection.GeneratedProtocolMessageType('BKArcRights', (_message.Message,), {
  'DESCRIPTOR' : _BKARCRIGHTS,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKArcRights)
  })
_sym_db.RegisterMessage(BKArcRights)

BKStat = _reflection.GeneratedProtocolMessageType('BKStat', (_message.Message,), {
  'DESCRIPTOR' : _BKSTAT,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.BKStat)
  })
_sym_db.RegisterMessage(BKStat)

CardModule = _reflection.GeneratedProtocolMessageType('CardModule', (_message.Message,), {
  'DESCRIPTOR' : _CARDMODULE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.CardModule)
  })
_sym_db.RegisterMessage(CardModule)

CoinAddReq = _reflection.GeneratedProtocolMessageType('CoinAddReq', (_message.Message,), {
  'DESCRIPTOR' : _COINADDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.CoinAddReq)
  })
_sym_db.RegisterMessage(CoinAddReq)

CoinAddResp = _reflection.GeneratedProtocolMessageType('CoinAddResp', (_message.Message,), {
  'DESCRIPTOR' : _COINADDRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.CoinAddResp)
  })
_sym_db.RegisterMessage(CoinAddResp)

DashItem = _reflection.GeneratedProtocolMessageType('DashItem', (_message.Message,), {
  'DESCRIPTOR' : _DASHITEM,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.DashItem)
  })
_sym_db.RegisterMessage(DashItem)

DashSegmentBase = _reflection.GeneratedProtocolMessageType('DashSegmentBase', (_message.Message,), {
  'DESCRIPTOR' : _DASHSEGMENTBASE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.DashSegmentBase)
  })
_sym_db.RegisterMessage(DashSegmentBase)

DetailItem = _reflection.GeneratedProtocolMessageType('DetailItem', (_message.Message,), {

  'PlayerInfoEntry' : _reflection.GeneratedProtocolMessageType('PlayerInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _DETAILITEM_PLAYERINFOENTRY,
    '__module__' : 'bilibili.app.listener.v1.listener_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.DetailItem.PlayerInfoEntry)
    })
  ,
  'DESCRIPTOR' : _DETAILITEM,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.DetailItem)
  })
_sym_db.RegisterMessage(DetailItem)
_sym_db.RegisterMessage(DetailItem.PlayerInfoEntry)

EventTracking = _reflection.GeneratedProtocolMessageType('EventTracking', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTRACKING,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.EventTracking)
  })
_sym_db.RegisterMessage(EventTracking)

FavFolder = _reflection.GeneratedProtocolMessageType('FavFolder', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDER,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolder)
  })
_sym_db.RegisterMessage(FavFolder)

FavFolderAction = _reflection.GeneratedProtocolMessageType('FavFolderAction', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERACTION,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderAction)
  })
_sym_db.RegisterMessage(FavFolderAction)

FavFolderAuthor = _reflection.GeneratedProtocolMessageType('FavFolderAuthor', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERAUTHOR,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderAuthor)
  })
_sym_db.RegisterMessage(FavFolderAuthor)

FavFolderCreateReq = _reflection.GeneratedProtocolMessageType('FavFolderCreateReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERCREATEREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderCreateReq)
  })
_sym_db.RegisterMessage(FavFolderCreateReq)

FavFolderCreateResp = _reflection.GeneratedProtocolMessageType('FavFolderCreateResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERCREATERESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderCreateResp)
  })
_sym_db.RegisterMessage(FavFolderCreateResp)

FavFolderDeleteReq = _reflection.GeneratedProtocolMessageType('FavFolderDeleteReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERDELETEREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderDeleteReq)
  })
_sym_db.RegisterMessage(FavFolderDeleteReq)

FavFolderDeleteResp = _reflection.GeneratedProtocolMessageType('FavFolderDeleteResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERDELETERESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderDeleteResp)
  })
_sym_db.RegisterMessage(FavFolderDeleteResp)

FavFolderDetailReq = _reflection.GeneratedProtocolMessageType('FavFolderDetailReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERDETAILREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderDetailReq)
  })
_sym_db.RegisterMessage(FavFolderDetailReq)

FavFolderDetailResp = _reflection.GeneratedProtocolMessageType('FavFolderDetailResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERDETAILRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderDetailResp)
  })
_sym_db.RegisterMessage(FavFolderDetailResp)

FavFolderListReq = _reflection.GeneratedProtocolMessageType('FavFolderListReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERLISTREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderListReq)
  })
_sym_db.RegisterMessage(FavFolderListReq)

FavFolderListResp = _reflection.GeneratedProtocolMessageType('FavFolderListResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERLISTRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderListResp)
  })
_sym_db.RegisterMessage(FavFolderListResp)

FavFolderMeta = _reflection.GeneratedProtocolMessageType('FavFolderMeta', (_message.Message,), {
  'DESCRIPTOR' : _FAVFOLDERMETA,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavFolderMeta)
  })
_sym_db.RegisterMessage(FavFolderMeta)

FavItem = _reflection.GeneratedProtocolMessageType('FavItem', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEM,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItem)
  })
_sym_db.RegisterMessage(FavItem)

FavItemAddReq = _reflection.GeneratedProtocolMessageType('FavItemAddReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMADDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemAddReq)
  })
_sym_db.RegisterMessage(FavItemAddReq)

FavItemAddResp = _reflection.GeneratedProtocolMessageType('FavItemAddResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMADDRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemAddResp)
  })
_sym_db.RegisterMessage(FavItemAddResp)

FavItemAuthor = _reflection.GeneratedProtocolMessageType('FavItemAuthor', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMAUTHOR,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemAuthor)
  })
_sym_db.RegisterMessage(FavItemAuthor)

FavItemBatchReq = _reflection.GeneratedProtocolMessageType('FavItemBatchReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMBATCHREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemBatchReq)
  })
_sym_db.RegisterMessage(FavItemBatchReq)

FavItemBatchResp = _reflection.GeneratedProtocolMessageType('FavItemBatchResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMBATCHRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemBatchResp)
  })
_sym_db.RegisterMessage(FavItemBatchResp)

FavItemDelReq = _reflection.GeneratedProtocolMessageType('FavItemDelReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMDELREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemDelReq)
  })
_sym_db.RegisterMessage(FavItemDelReq)

FavItemDelResp = _reflection.GeneratedProtocolMessageType('FavItemDelResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMDELRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemDelResp)
  })
_sym_db.RegisterMessage(FavItemDelResp)

FavItemDetail = _reflection.GeneratedProtocolMessageType('FavItemDetail', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMDETAIL,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemDetail)
  })
_sym_db.RegisterMessage(FavItemDetail)

FavItemStat = _reflection.GeneratedProtocolMessageType('FavItemStat', (_message.Message,), {
  'DESCRIPTOR' : _FAVITEMSTAT,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavItemStat)
  })
_sym_db.RegisterMessage(FavItemStat)

FavoredInAnyFoldersReq = _reflection.GeneratedProtocolMessageType('FavoredInAnyFoldersReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVOREDINANYFOLDERSREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavoredInAnyFoldersReq)
  })
_sym_db.RegisterMessage(FavoredInAnyFoldersReq)

FavoredInAnyFoldersResp = _reflection.GeneratedProtocolMessageType('FavoredInAnyFoldersResp', (_message.Message,), {
  'DESCRIPTOR' : _FAVOREDINANYFOLDERSRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FavoredInAnyFoldersResp)
  })
_sym_db.RegisterMessage(FavoredInAnyFoldersResp)

FollowRelation = _reflection.GeneratedProtocolMessageType('FollowRelation', (_message.Message,), {
  'DESCRIPTOR' : _FOLLOWRELATION,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FollowRelation)
  })
_sym_db.RegisterMessage(FollowRelation)

FormatDescription = _reflection.GeneratedProtocolMessageType('FormatDescription', (_message.Message,), {
  'DESCRIPTOR' : _FORMATDESCRIPTION,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.FormatDescription)
  })
_sym_db.RegisterMessage(FormatDescription)

PageOption = _reflection.GeneratedProtocolMessageType('PageOption', (_message.Message,), {
  'DESCRIPTOR' : _PAGEOPTION,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PageOption)
  })
_sym_db.RegisterMessage(PageOption)

PickArchive = _reflection.GeneratedProtocolMessageType('PickArchive', (_message.Message,), {
  'DESCRIPTOR' : _PICKARCHIVE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickArchive)
  })
_sym_db.RegisterMessage(PickArchive)

PickArchiveAuthor = _reflection.GeneratedProtocolMessageType('PickArchiveAuthor', (_message.Message,), {
  'DESCRIPTOR' : _PICKARCHIVEAUTHOR,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickArchiveAuthor)
  })
_sym_db.RegisterMessage(PickArchiveAuthor)

PickCard = _reflection.GeneratedProtocolMessageType('PickCard', (_message.Message,), {
  'DESCRIPTOR' : _PICKCARD,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickCard)
  })
_sym_db.RegisterMessage(PickCard)

PickCardDetailReq = _reflection.GeneratedProtocolMessageType('PickCardDetailReq', (_message.Message,), {
  'DESCRIPTOR' : _PICKCARDDETAILREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickCardDetailReq)
  })
_sym_db.RegisterMessage(PickCardDetailReq)

PickCardDetailResp = _reflection.GeneratedProtocolMessageType('PickCardDetailResp', (_message.Message,), {
  'DESCRIPTOR' : _PICKCARDDETAILRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickCardDetailResp)
  })
_sym_db.RegisterMessage(PickCardDetailResp)

PickFeedReq = _reflection.GeneratedProtocolMessageType('PickFeedReq', (_message.Message,), {
  'DESCRIPTOR' : _PICKFEEDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickFeedReq)
  })
_sym_db.RegisterMessage(PickFeedReq)

PickFeedResp = _reflection.GeneratedProtocolMessageType('PickFeedResp', (_message.Message,), {
  'DESCRIPTOR' : _PICKFEEDRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PickFeedResp)
  })
_sym_db.RegisterMessage(PickFeedResp)

PkcmArchive = _reflection.GeneratedProtocolMessageType('PkcmArchive', (_message.Message,), {
  'DESCRIPTOR' : _PKCMARCHIVE,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PkcmArchive)
  })
_sym_db.RegisterMessage(PkcmArchive)

PkcmCenterButton = _reflection.GeneratedProtocolMessageType('PkcmCenterButton', (_message.Message,), {
  'DESCRIPTOR' : _PKCMCENTERBUTTON,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PkcmCenterButton)
  })
_sym_db.RegisterMessage(PkcmCenterButton)

PkcmHeader = _reflection.GeneratedProtocolMessageType('PkcmHeader', (_message.Message,), {
  'DESCRIPTOR' : _PKCMHEADER,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PkcmHeader)
  })
_sym_db.RegisterMessage(PkcmHeader)

PlayActionReportReq = _reflection.GeneratedProtocolMessageType('PlayActionReportReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYACTIONREPORTREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayActionReportReq)
  })
_sym_db.RegisterMessage(PlayActionReportReq)

PlayDASH = _reflection.GeneratedProtocolMessageType('PlayDASH', (_message.Message,), {
  'DESCRIPTOR' : _PLAYDASH,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayDASH)
  })
_sym_db.RegisterMessage(PlayDASH)

PlayHistoryAddReq = _reflection.GeneratedProtocolMessageType('PlayHistoryAddReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYHISTORYADDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayHistoryAddReq)
  })
_sym_db.RegisterMessage(PlayHistoryAddReq)

PlayHistoryDelReq = _reflection.GeneratedProtocolMessageType('PlayHistoryDelReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYHISTORYDELREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayHistoryDelReq)
  })
_sym_db.RegisterMessage(PlayHistoryDelReq)

PlayHistoryReq = _reflection.GeneratedProtocolMessageType('PlayHistoryReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYHISTORYREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayHistoryReq)
  })
_sym_db.RegisterMessage(PlayHistoryReq)

PlayHistoryResp = _reflection.GeneratedProtocolMessageType('PlayHistoryResp', (_message.Message,), {
  'DESCRIPTOR' : _PLAYHISTORYRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayHistoryResp)
  })
_sym_db.RegisterMessage(PlayHistoryResp)

PlayInfo = _reflection.GeneratedProtocolMessageType('PlayInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLAYINFO,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayInfo)
  })
_sym_db.RegisterMessage(PlayInfo)

PlayItem = _reflection.GeneratedProtocolMessageType('PlayItem', (_message.Message,), {
  'DESCRIPTOR' : _PLAYITEM,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayItem)
  })
_sym_db.RegisterMessage(PlayItem)

PlaylistAddReq = _reflection.GeneratedProtocolMessageType('PlaylistAddReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYLISTADDREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlaylistAddReq)
  })
_sym_db.RegisterMessage(PlaylistAddReq)

PlaylistDelReq = _reflection.GeneratedProtocolMessageType('PlaylistDelReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYLISTDELREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlaylistDelReq)
  })
_sym_db.RegisterMessage(PlaylistDelReq)

PlaylistReq = _reflection.GeneratedProtocolMessageType('PlaylistReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYLISTREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlaylistReq)
  })
_sym_db.RegisterMessage(PlaylistReq)

PlaylistResp = _reflection.GeneratedProtocolMessageType('PlaylistResp', (_message.Message,), {
  'DESCRIPTOR' : _PLAYLISTRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlaylistResp)
  })
_sym_db.RegisterMessage(PlaylistResp)

PlayURL = _reflection.GeneratedProtocolMessageType('PlayURL', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURL,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayURL)
  })
_sym_db.RegisterMessage(PlayURL)

PlayURLReq = _reflection.GeneratedProtocolMessageType('PlayURLReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYURLREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayURLReq)
  })
_sym_db.RegisterMessage(PlayURLReq)

PlayURLResp = _reflection.GeneratedProtocolMessageType('PlayURLResp', (_message.Message,), {

  'PlayerInfoEntry' : _reflection.GeneratedProtocolMessageType('PlayerInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLAYURLRESP_PLAYERINFOENTRY,
    '__module__' : 'bilibili.app.listener.v1.listener_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayURLResp.PlayerInfoEntry)
    })
  ,
  'DESCRIPTOR' : _PLAYURLRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.PlayURLResp)
  })
_sym_db.RegisterMessage(PlayURLResp)
_sym_db.RegisterMessage(PlayURLResp.PlayerInfoEntry)

RcmdPlaylistReq = _reflection.GeneratedProtocolMessageType('RcmdPlaylistReq', (_message.Message,), {
  'DESCRIPTOR' : _RCMDPLAYLISTREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.RcmdPlaylistReq)
  })
_sym_db.RegisterMessage(RcmdPlaylistReq)

RcmdPlaylistResp = _reflection.GeneratedProtocolMessageType('RcmdPlaylistResp', (_message.Message,), {
  'DESCRIPTOR' : _RCMDPLAYLISTRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.RcmdPlaylistResp)
  })
_sym_db.RegisterMessage(RcmdPlaylistResp)

ResponseUrl = _reflection.GeneratedProtocolMessageType('ResponseUrl', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEURL,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.ResponseUrl)
  })
_sym_db.RegisterMessage(ResponseUrl)

ThumbUpReq = _reflection.GeneratedProtocolMessageType('ThumbUpReq', (_message.Message,), {
  'DESCRIPTOR' : _THUMBUPREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.ThumbUpReq)
  })
_sym_db.RegisterMessage(ThumbUpReq)

ThumbUpResp = _reflection.GeneratedProtocolMessageType('ThumbUpResp', (_message.Message,), {
  'DESCRIPTOR' : _THUMBUPRESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.ThumbUpResp)
  })
_sym_db.RegisterMessage(ThumbUpResp)

TripleLikeReq = _reflection.GeneratedProtocolMessageType('TripleLikeReq', (_message.Message,), {
  'DESCRIPTOR' : _TRIPLELIKEREQ,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.TripleLikeReq)
  })
_sym_db.RegisterMessage(TripleLikeReq)

TripleLikeResp = _reflection.GeneratedProtocolMessageType('TripleLikeResp', (_message.Message,), {
  'DESCRIPTOR' : _TRIPLELIKERESP,
  '__module__' : 'bilibili.app.listener.v1.listener_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.listener.v1.TripleLikeResp)
  })
_sym_db.RegisterMessage(TripleLikeResp)

_LISTENER = DESCRIPTOR.services_by_name['Listener']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETAILITEM_PLAYERINFOENTRY._options = None
  _DETAILITEM_PLAYERINFOENTRY._serialized_options = b'8\001'
  _PLAYURLRESP_PLAYERINFOENTRY._options = None
  _PLAYURLRESP_PLAYERINFOENTRY._serialized_options = b'8\001'
  _CARDMODULETYPE._serialized_start=8849
  _CARDMODULETYPE._serialized_end=8941
  _PLAYLISTSOURCE._serialized_start=8944
  _PLAYLISTSOURCE._serialized_end=9094
  _AUTHOR._serialized_start=148
  _AUTHOR._serialized_end=259
  _BKARCDETAILSREQ._serialized_start=262
  _BKARCDETAILSREQ._serialized_end=398
  _BKARCDETAILSRESP._serialized_start=400
  _BKARCDETAILSRESP._serialized_end=470
  _BKARCHIVE._serialized_start=473
  _BKARCHIVE._serialized_end=701
  _BKARCPART._serialized_start=703
  _BKARCPART._serialized_end=790
  _BKARCRIGHTS._serialized_start=792
  _BKARCRIGHTS._serialized_end=825
  _BKSTAT._serialized_start=828
  _BKSTAT._serialized_end=980
  _CARDMODULE._serialized_start=983
  _CARDMODULE._serialized_end=1221
  _COINADDREQ._serialized_start=1223
  _COINADDREQ._serialized_end=1316
  _COINADDRESP._serialized_start=1318
  _COINADDRESP._serialized_end=1348
  _DASHITEM._serialized_start=1351
  _DASHITEM._serialized_end=1574
  _DASHSEGMENTBASE._serialized_start=1576
  _DASHSEGMENTBASE._serialized_end=1638
  _DETAILITEM._serialized_start=1641
  _DETAILITEM._serialized_end=2136
  _DETAILITEM_PLAYERINFOENTRY._serialized_start=2051
  _DETAILITEM_PLAYERINFOENTRY._serialized_end=2136
  _EVENTTRACKING._serialized_start=2138
  _EVENTTRACKING._serialized_end=2244
  _FAVFOLDER._serialized_start=2247
  _FAVFOLDER._serialized_end=2619
  _FAVFOLDERACTION._serialized_start=2621
  _FAVFOLDERACTION._serialized_end=2688
  _FAVFOLDERAUTHOR._serialized_start=2690
  _FAVFOLDERAUTHOR._serialized_end=2734
  _FAVFOLDERCREATEREQ._serialized_start=2736
  _FAVFOLDERCREATEREQ._serialized_end=2821
  _FAVFOLDERCREATERESP._serialized_start=2823
  _FAVFOLDERCREATERESP._serialized_end=2895
  _FAVFOLDERDELETEREQ._serialized_start=2897
  _FAVFOLDERDELETEREQ._serialized_end=2951
  _FAVFOLDERDELETERESP._serialized_start=2953
  _FAVFOLDERDELETERESP._serialized_end=2991
  _FAVFOLDERDETAILREQ._serialized_start=2994
  _FAVFOLDERDETAILREQ._serialized_end=3164
  _FAVFOLDERDETAILRESP._serialized_start=3167
  _FAVFOLDERDETAILRESP._serialized_end=3335
  _FAVFOLDERLISTREQ._serialized_start=3337
  _FAVFOLDERLISTREQ._serialized_end=3427
  _FAVFOLDERLISTRESP._serialized_start=3429
  _FAVFOLDERLISTRESP._serialized_end=3499
  _FAVFOLDERMETA._serialized_start=3501
  _FAVFOLDERMETA._serialized_end=3550
  _FAVITEM._serialized_start=3553
  _FAVITEM._serialized_end=3703
  _FAVITEMADDREQ._serialized_start=3706
  _FAVITEMADDREQ._serialized_end=3865
  _FAVITEMADDRESP._serialized_start=3867
  _FAVITEMADDRESP._serialized_end=3900
  _FAVITEMAUTHOR._serialized_start=3902
  _FAVITEMAUTHOR._serialized_end=3944
  _FAVITEMBATCHREQ._serialized_start=3947
  _FAVITEMBATCHREQ._serialized_end=4134
  _FAVITEMBATCHRESP._serialized_start=4136
  _FAVITEMBATCHRESP._serialized_end=4171
  _FAVITEMDELREQ._serialized_start=4174
  _FAVITEMDELREQ._serialized_end=4333
  _FAVITEMDELRESP._serialized_start=4335
  _FAVITEMDELRESP._serialized_end=4368
  _FAVITEMDETAIL._serialized_start=4371
  _FAVITEMDETAIL._serialized_end=4638
  _FAVITEMSTAT._serialized_start=4640
  _FAVITEMSTAT._serialized_end=4682
  _FAVOREDINANYFOLDERSREQ._serialized_start=4684
  _FAVOREDINANYFOLDERSREQ._serialized_end=4780
  _FAVOREDINANYFOLDERSRESP._serialized_start=4783
  _FAVOREDINANYFOLDERSRESP._serialized_end=4916
  _FOLLOWRELATION._serialized_start=4918
  _FOLLOWRELATION._serialized_end=4950
  _FORMATDESCRIPTION._serialized_start=4952
  _FORMATDESCRIPTION._serialized_end=5068
  _PAGEOPTION._serialized_start=5070
  _PAGEOPTION._serialized_end=5175
  _PICKARCHIVE._serialized_start=5178
  _PICKARCHIVE._serialized_end=5435
  _PICKARCHIVEAUTHOR._serialized_start=5437
  _PICKARCHIVEAUTHOR._serialized_end=5483
  _PICKCARD._serialized_start=5485
  _PICKCARD._serialized_end=5603
  _PICKCARDDETAILREQ._serialized_start=5605
  _PICKCARDDETAILREQ._serialized_end=5658
  _PICKCARDDETAILRESP._serialized_start=5660
  _PICKCARDDETAILRESP._serialized_end=5769
  _PICKFEEDREQ._serialized_start=5771
  _PICKFEEDREQ._serialized_end=5800
  _PICKFEEDRESP._serialized_start=5802
  _PICKFEEDRESP._serialized_end=5883
  _PKCMARCHIVE._serialized_start=5885
  _PKCMARCHIVE._serialized_end=5971
  _PKCMCENTERBUTTON._serialized_start=5973
  _PKCMCENTERBUTTON._serialized_end=6057
  _PKCMHEADER._serialized_start=6059
  _PKCMHEADER._serialized_end=6153
  _PLAYACTIONREPORTREQ._serialized_start=6155
  _PLAYACTIONREPORTREQ._serialized_end=6226
  _PLAYDASH._serialized_start=6228
  _PLAYDASH._serialized_end=6332
  _PLAYHISTORYADDREQ._serialized_start=6334
  _PLAYHISTORYADDREQ._serialized_end=6459
  _PLAYHISTORYDELREQ._serialized_start=6461
  _PLAYHISTORYDELREQ._serialized_end=6549
  _PLAYHISTORYREQ._serialized_start=6551
  _PLAYHISTORYREQ._serialized_end=6623
  _PLAYHISTORYRESP._serialized_start=6625
  _PLAYHISTORYRESP._serialized_end=6728
  _PLAYINFO._serialized_start=6731
  _PLAYINFO._serialized_end=7023
  _PLAYITEM._serialized_start=7025
  _PLAYITEM._serialized_end=7136
  _PLAYLISTADDREQ._serialized_start=7139
  _PLAYLISTADDREQ._serialized_end=7298
  _PLAYLISTDELREQ._serialized_start=7300
  _PLAYLISTDELREQ._serialized_end=7385
  _PLAYLISTREQ._serialized_start=7388
  _PLAYLISTREQ._serialized_end=7622
  _PLAYLISTRESP._serialized_start=7625
  _PLAYLISTRESP._serialized_end=7824
  _PLAYURL._serialized_start=7826
  _PLAYURL._serialized_end=7888
  _PLAYURLREQ._serialized_start=7891
  _PLAYURLREQ._serialized_end=8022
  _PLAYURLRESP._serialized_start=8025
  _PLAYURLRESP._serialized_end=8285
  _PLAYURLRESP_PLAYERINFOENTRY._serialized_start=2051
  _PLAYURLRESP_PLAYERINFOENTRY._serialized_end=2136
  _RCMDPLAYLISTREQ._serialized_start=8287
  _RCMDPLAYLISTREQ._serialized_end=8352
  _RCMDPLAYLISTRESP._serialized_start=8354
  _RCMDPLAYLISTRESP._serialized_end=8445
  _RESPONSEURL._serialized_start=8448
  _RESPONSEURL._serialized_end=8582
  _THUMBUPREQ._serialized_start=8584
  _THUMBUPREQ._serialized_end=8662
  _THUMBUPRESP._serialized_start=8664
  _THUMBUPRESP._serialized_end=8694
  _TRIPLELIKEREQ._serialized_start=8696
  _TRIPLELIKEREQ._serialized_end=8761
  _TRIPLELIKERESP._serialized_start=8763
  _TRIPLELIKERESP._serialized_end=8847
  _LISTENER._serialized_start=9097
  _LISTENER._serialized_end=11411
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LiveStartEvent(google.protobuf.message.Message):
    """开播事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___LiveStartEvent = LiveStartEvent

class LiveEndEvent(google.protobuf.message.Message):
    """直播中止事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___LiveEndEvent = LiveEndEvent

class LiveOnlineEvent(google.protobuf.message.Message):
    """在线人数事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ONLINE_FIELD_NUMBER: builtins.int
    online: builtins.int
    """在线人数"""

    def __init__(self,
        *,
        online: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["online",b"online"]) -> None: ...
global___LiveOnlineEvent = LiveOnlineEvent

class LiveUpdateEvent(google.protobuf.message.Message):
    """变更通知"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AFTER_PREMIERE_TYPE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    after_premiere_type: builtins.int
    """直播后状态
    1:下线 2:转点播
    """

    start_time: builtins.int
    """直播开始绝对时间 单位ms"""

    id: typing.Text
    """id"""

    progress: builtins.int
    """服务端播放进度，未打散，负数表示距离开播时间，正数表示已开播时间，单位：毫秒
    用户实际播放进度：progress - delay_time
    """

    def __init__(self,
        *,
        after_premiere_type: builtins.int = ...,
        start_time: builtins.int = ...,
        id: typing.Text = ...,
        progress: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_premiere_type",b"after_premiere_type","id",b"id","progress",b"progress","start_time",b"start_time"]) -> None: ...
global___LiveUpdateEvent = LiveUpdateEvent

class CMDBody(google.protobuf.message.Message):
    """直播间事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_FIELD_NUMBER: builtins.int
    EMERGENCY_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    @property
    def start(self) -> global___LiveStartEvent:
        """开播事件"""
        pass
    @property
    def emergency(self) -> global___LiveEndEvent:
        """直播中止事件"""
        pass
    @property
    def online(self) -> global___LiveOnlineEvent:
        """在线人数事件"""
        pass
    @property
    def update(self) -> global___LiveUpdateEvent:
        """变更通知"""
        pass
    def __init__(self,
        *,
        start: typing.Optional[global___LiveStartEvent] = ...,
        emergency: typing.Optional[global___LiveEndEvent] = ...,
        online: typing.Optional[global___LiveOnlineEvent] = ...,
        update: typing.Optional[global___LiveUpdateEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["emergency",b"emergency","event",b"event","online",b"online","start",b"start","update",b"update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["emergency",b"emergency","event",b"event","online",b"online","start",b"start","update",b"update"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event",b"event"]) -> typing.Optional[typing_extensions.Literal["start","emergency","online","update"]]: ...
global___CMDBody = CMDBody



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/polymer/contract/contract.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/polymer/contract/contract.proto\x12\x19\x62ilibili.polymer.contract\x1a\x1bgoogle/protobuf/empty.proto\"p\n\x0e\x41\x64\x64\x43ontractReq\x12\x34\n\x06\x63ommon\x18\x01 \x01(\x0b\x32$.bilibili.polymer.contract.CommonReq\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\"x\n\tCommonReq\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05\x62uild\x18\x02 \x01(\x05\x12\r\n\x05\x62uvid\x18\x03 \x01(\t\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\t\x12\r\n\x05spmid\x18\x07 \x01(\t2\\\n\x08\x43ontract\x12P\n\x0b\x41\x64\x64\x43ontract\x12).bilibili.polymer.contract.AddContractReq\x1a\x16.google.protobuf.Emptyb\x06proto3')



_ADDCONTRACTREQ = DESCRIPTOR.message_types_by_name['AddContractReq']
_COMMONREQ = DESCRIPTOR.message_types_by_name['CommonReq']
AddContractReq = _reflection.GeneratedProtocolMessageType('AddContractReq', (_message.Message,), {
  'DESCRIPTOR' : _ADDCONTRACTREQ,
  '__module__' : 'bilibili.polymer.contract.contract_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.contract.AddContractReq)
  })
_sym_db.RegisterMessage(AddContractReq)

CommonReq = _reflection.GeneratedProtocolMessageType('CommonReq', (_message.Message,), {
  'DESCRIPTOR' : _COMMONREQ,
  '__module__' : 'bilibili.polymer.contract.contract_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.contract.CommonReq)
  })
_sym_db.RegisterMessage(CommonReq)

_CONTRACT = DESCRIPTOR.services_by_name['Contract']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADDCONTRACTREQ._serialized_start=100
  _ADDCONTRACTREQ._serialized_end=212
  _COMMONREQ._serialized_start=214
  _COMMONREQ._serialized_end=334
  _CONTRACT._serialized_start=336
  _CONTRACT._serialized_end=428
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/account/fission/v1/fission.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/account/fission/v1/fission.proto\x12\x1b\x62ilibili.account.fission.v1\"\r\n\x0b\x45ntranceReq\"x\n\rEntranceReply\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12>\n\x0c\x61nimate_icon\x18\x04 \x01(\x0b\x32(.bilibili.account.fission.v1.AnimateIcon\"\x0b\n\tWindowReq\"=\n\x0bWindowReply\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x13\n\x0breport_data\x18\x03 \x01(\t\")\n\x0b\x41nimateIcon\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04json\x18\x02 \x01(\t2\xc7\x01\n\x07\x46ission\x12`\n\x08\x45ntrance\x12(.bilibili.account.fission.v1.EntranceReq\x1a*.bilibili.account.fission.v1.EntranceReply\x12Z\n\x06Window\x12&.bilibili.account.fission.v1.WindowReq\x1a(.bilibili.account.fission.v1.WindowReplyb\x06proto3')



_ENTRANCEREQ = DESCRIPTOR.message_types_by_name['EntranceReq']
_ENTRANCEREPLY = DESCRIPTOR.message_types_by_name['EntranceReply']
_WINDOWREQ = DESCRIPTOR.message_types_by_name['WindowReq']
_WINDOWREPLY = DESCRIPTOR.message_types_by_name['WindowReply']
_ANIMATEICON = DESCRIPTOR.message_types_by_name['AnimateIcon']
EntranceReq = _reflection.GeneratedProtocolMessageType('EntranceReq', (_message.Message,), {
  'DESCRIPTOR' : _ENTRANCEREQ,
  '__module__' : 'bilibili.account.fission.v1.fission_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.account.fission.v1.EntranceReq)
  })
_sym_db.RegisterMessage(EntranceReq)

EntranceReply = _reflection.GeneratedProtocolMessageType('EntranceReply', (_message.Message,), {
  'DESCRIPTOR' : _ENTRANCEREPLY,
  '__module__' : 'bilibili.account.fission.v1.fission_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.account.fission.v1.EntranceReply)
  })
_sym_db.RegisterMessage(EntranceReply)

WindowReq = _reflection.GeneratedProtocolMessageType('WindowReq', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWREQ,
  '__module__' : 'bilibili.account.fission.v1.fission_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.account.fission.v1.WindowReq)
  })
_sym_db.RegisterMessage(WindowReq)

WindowReply = _reflection.GeneratedProtocolMessageType('WindowReply', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWREPLY,
  '__module__' : 'bilibili.account.fission.v1.fission_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.account.fission.v1.WindowReply)
  })
_sym_db.RegisterMessage(WindowReply)

AnimateIcon = _reflection.GeneratedProtocolMessageType('AnimateIcon', (_message.Message,), {
  'DESCRIPTOR' : _ANIMATEICON,
  '__module__' : 'bilibili.account.fission.v1.fission_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.account.fission.v1.AnimateIcon)
  })
_sym_db.RegisterMessage(AnimateIcon)

_FISSION = DESCRIPTOR.services_by_name['Fission']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENTRANCEREQ._serialized_start=74
  _ENTRANCEREQ._serialized_end=87
  _ENTRANCEREPLY._serialized_start=89
  _ENTRANCEREPLY._serialized_end=209
  _WINDOWREQ._serialized_start=211
  _WINDOWREQ._serialized_end=222
  _WINDOWREPLY._serialized_start=224
  _WINDOWREPLY._serialized_end=285
  _ANIMATEICON._serialized_start=287
  _ANIMATEICON._serialized_end=328
  _FISSION._serialized_start=331
  _FISSION._serialized_end=530
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/metadata/network/network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/metadata/network/network.proto\x12\x19\x62ilibili.metadata.network\"{\n\x07Network\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.bilibili.metadata.network.NetworkType\x12-\n\x02tf\x18\x02 \x01(\x0e\x32!.bilibili.metadata.network.TFType\x12\x0b\n\x03oid\x18\x03 \x01(\t*^\n\x0bNetworkType\x12\x0e\n\nNT_UNKNOWN\x10\x00\x12\x08\n\x04WIFI\x10\x01\x12\x0c\n\x08\x43\x45LLULAR\x10\x02\x12\x0b\n\x07OFFLINE\x10\x03\x12\x0c\n\x08OTHERNET\x10\x04\x12\x0c\n\x08\x45THERNET\x10\x05*]\n\x06TFType\x12\x0e\n\nTF_UNKNOWN\x10\x00\x12\n\n\x06U_CARD\x10\x01\x12\t\n\x05U_PKG\x10\x02\x12\n\n\x06\x43_CARD\x10\x03\x12\t\n\x05\x43_PKG\x10\x04\x12\n\n\x06T_CARD\x10\x05\x12\t\n\x05T_PKG\x10\x06\x62\x06proto3')

_NETWORKTYPE = DESCRIPTOR.enum_types_by_name['NetworkType']
NetworkType = enum_type_wrapper.EnumTypeWrapper(_NETWORKTYPE)
_TFTYPE = DESCRIPTOR.enum_types_by_name['TFType']
TFType = enum_type_wrapper.EnumTypeWrapper(_TFTYPE)
NT_UNKNOWN = 0
WIFI = 1
CELLULAR = 2
OFFLINE = 3
OTHERNET = 4
ETHERNET = 5
TF_UNKNOWN = 0
U_CARD = 1
U_PKG = 2
C_CARD = 3
C_PKG = 4
T_CARD = 5
T_PKG = 6


_NETWORK = DESCRIPTOR.message_types_by_name['Network']
Network = _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
  'DESCRIPTOR' : _NETWORK,
  '__module__' : 'bilibili.metadata.network.network_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.metadata.network.Network)
  })
_sym_db.RegisterMessage(Network)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKTYPE._serialized_start=195
  _NETWORKTYPE._serialized_end=289
  _TFTYPE._serialized_start=291
  _TFTYPE._serialized_end=384
  _NETWORK._serialized_start=70
  _NETWORK._serialized_end=193
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.rpc.status_pb2
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RoomErrorEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def status(self) -> bilibili.rpc.status_pb2.Status:
        """"""
        pass
    def __init__(self,
        *,
        status: typing.Optional[bilibili.rpc.status_pb2.Status] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["status",b"status"]) -> None: ...
global___RoomErrorEvent = RoomErrorEvent

class RoomJoinEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RoomJoinEvent = RoomJoinEvent

class RoomLeaveEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RoomLeaveEvent = RoomLeaveEvent

class RoomMessageEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TARGET_PATH_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    target_path: typing.Text
    """"""

    @property
    def body(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    def __init__(self,
        *,
        target_path: typing.Text = ...,
        body: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body",b"body"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body",b"body","target_path",b"target_path"]) -> None: ...
global___RoomMessageEvent = RoomMessageEvent

class RoomOnlineEvent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ONLINE_FIELD_NUMBER: builtins.int
    ALL_ONLINE_FIELD_NUMBER: builtins.int
    online: builtins.int
    """"""

    all_online: builtins.int
    """"""

    def __init__(self,
        *,
        online: builtins.int = ...,
        all_online: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_online",b"all_online","online",b"online"]) -> None: ...
global___RoomOnlineEvent = RoomOnlineEvent

class RoomReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    JOIN_FIELD_NUMBER: builtins.int
    LEAVE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    id: typing.Text
    """{type}://{room_id}"""

    @property
    def join(self) -> global___RoomJoinEvent:
        """"""
        pass
    @property
    def leave(self) -> global___RoomLeaveEvent:
        """"""
        pass
    @property
    def online(self) -> global___RoomOnlineEvent:
        """"""
        pass
    @property
    def msg(self) -> global___RoomMessageEvent:
        """"""
        pass
    def __init__(self,
        *,
        id: typing.Text = ...,
        join: typing.Optional[global___RoomJoinEvent] = ...,
        leave: typing.Optional[global___RoomLeaveEvent] = ...,
        online: typing.Optional[global___RoomOnlineEvent] = ...,
        msg: typing.Optional[global___RoomMessageEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event",b"event","join",b"join","leave",b"leave","msg",b"msg","online",b"online"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event",b"event","id",b"id","join",b"join","leave",b"leave","msg",b"msg","online",b"online"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event",b"event"]) -> typing.Optional[typing_extensions.Literal["join","leave","online","msg"]]: ...
global___RoomReq = RoomReq

class RoomResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    JOIN_FIELD_NUMBER: builtins.int
    LEAVE_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    ERR_FIELD_NUMBER: builtins.int
    id: typing.Text
    """{type}://{room_id}"""

    @property
    def join(self) -> global___RoomJoinEvent:
        """"""
        pass
    @property
    def leave(self) -> global___RoomLeaveEvent:
        """"""
        pass
    @property
    def online(self) -> global___RoomOnlineEvent:
        """"""
        pass
    @property
    def msg(self) -> global___RoomMessageEvent:
        """"""
        pass
    @property
    def err(self) -> global___RoomErrorEvent:
        """"""
        pass
    def __init__(self,
        *,
        id: typing.Text = ...,
        join: typing.Optional[global___RoomJoinEvent] = ...,
        leave: typing.Optional[global___RoomLeaveEvent] = ...,
        online: typing.Optional[global___RoomOnlineEvent] = ...,
        msg: typing.Optional[global___RoomMessageEvent] = ...,
        err: typing.Optional[global___RoomErrorEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["err",b"err","event",b"event","join",b"join","leave",b"leave","msg",b"msg","online",b"online"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["err",b"err","event",b"event","id",b"id","join",b"join","leave",b"leave","msg",b"msg","online",b"online"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event",b"event"]) -> typing.Optional[typing_extensions.Literal["join","leave","online","msg","err"]]: ...
global___RoomResp = RoomResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/card/v1/single.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.card.v1 import common_pb2 as bilibili_dot_app_dot_card_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/card/v1/single.proto\x12\x14\x62ilibili.app.card.v1\x1a!bilibili/app/card/v1/common.proto\"\xe5\x03\n\x0cSmallCoverV5\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\tcover_gif\x18\x02 \x01(\t\x12$\n\x02up\x18\x03 \x01(\x0b\x32\x18.bilibili.app.card.v1.Up\x12\x1a\n\x12\x63over_right_text_1\x18\x04 \x01(\t\x12\x14\n\x0cright_desc_1\x18\x05 \x01(\t\x12\x14\n\x0cright_desc_2\x18\x06 \x01(\t\x12<\n\x11rcmd_reason_style\x18\x07 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12?\n\x10hotword_entrance\x18\x08 \x01(\x0b\x32%.bilibili.app.card.v1.HotwordEntrance\x12<\n\x11\x63orner_mark_style\x18\t \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x14\n\x0cright_icon_1\x18\n \x01(\x05\x12\x14\n\x0cright_icon_2\x18\x0b \x01(\x05\x12\x41\n\x16left_corner_mark_style\x18\x0c \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"U\n\x0fHotwordEntrance\x12\x12\n\nhotword_id\x18\x01 \x01(\x03\x12\x10\n\x08hot_text\x18\x02 \x01(\t\x12\x0e\n\x06h5_url\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\"\x9d\x06\n\x0cLargeCoverV1\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\tcover_gif\x18\x02 \x01(\t\x12,\n\x06\x61vatar\x18\x03 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Avatar\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x13\n\x0b\x63over_badge\x18\x07 \x01(\t\x12\x17\n\x0ftop_rcmd_reason\x18\x08 \x01(\t\x12\x1a\n\x12\x62ottom_rcmd_reason\x18\t \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\n \x01(\t\x12\x15\n\rofficial_icon\x18\x0b \x01(\x05\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x05\x12@\n\x15top_rcmd_reason_style\x18\r \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x43\n\x18\x62ottom_rcmd_reason_style\x18\x0e \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12?\n\x14rcmd_reason_style_v2\x18\x0f \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x41\n\x16left_cover_badge_style\x18\x10 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x42\n\x17right_cover_badge_style\x18\x11 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x15\n\rcover_badge_2\x18\x12 \x01(\t\x12\x35\n\x0blike_button\x18\x13 \x01(\x0b\x32 .bilibili.app.card.v1.LikeButton\x12\x19\n\x11title_single_line\x18\x14 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\x15 \x01(\t\"\xb0\x01\n\x0eThreeItemAllV2\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12@\n\x15top_rcmd_reason_style\x18\x02 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x32\n\x04item\x18\x03 \x03(\x0b\x32$.bilibili.app.card.v1.TwoItemHV1Item\"\xd2\x01\n\x0eTwoItemHV1Item\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05param\x18\x04 \x01(\t\x12(\n\x04\x61rgs\x18\x05 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Args\x12\x0c\n\x04goto\x18\x06 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x07 \x01(\t\x12\x19\n\x11\x63over_left_icon_1\x18\x08 \x01(\x05\x12\x18\n\x10\x63over_right_text\x18\t \x01(\t\"\xae\x01\n\x0bRcmdOneItem\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12=\n\x12topRcmdReasonStyle\x18\x02 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\x12\x36\n\x04item\x18\x03 \x01(\x0b\x32(.bilibili.app.card.v1.SmallCoverRcmdItem\"\xd7\x01\n\x12SmallCoverRcmdItem\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\r\n\x05param\x18\x04 \x01(\t\x12\x0c\n\x04goto\x18\x05 \x01(\t\x12\x17\n\x0f\x63overRightText1\x18\x06 \x01(\t\x12\x12\n\nrightDesc1\x18\x07 \x01(\t\x12\x12\n\nrightDesc2\x18\x08 \x01(\t\x12\x10\n\x08\x63overGif\x18\t \x01(\t\x12\x12\n\nrightIcon1\x18\n \x01(\x05\x12\x12\n\nrightIcon2\x18\x0b \x01(\x05\"\xa3\x01\n\x0bThreeItemV1\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x11\n\ttitleIcon\x18\x02 \x01(\x05\x12\x0f\n\x07moreUri\x18\x03 \x01(\t\x12\x10\n\x08moreText\x18\x04 \x01(\t\x12\x34\n\x05items\x18\x05 \x03(\x0b\x32%.bilibili.app.card.v1.ThreeItemV1Item\"\x96\x01\n\x0fThreeItemV1Item\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x15\n\rcoverLeftText\x18\x02 \x01(\t\x12\x15\n\rcoverLeftIcon\x18\x03 \x01(\x05\x12\r\n\x05\x64\x65sc1\x18\x04 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x05 \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x06 \x01(\t\"G\n\x0cHotTopicItem\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\r\n\x05param\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"u\n\x08HotTopic\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x31\n\x05items\x18\x03 \x03(\x0b\x32\".bilibili.app.card.v1.HotTopicItem\"\xfd\x01\n\nDynamicHot\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x16\n\x0etop_left_title\x18\x02 \x01(\t\x12\r\n\x05\x64\x65sc1\x18\x03 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x04 \x01(\t\x12\x10\n\x08more_uri\x18\x05 \x01(\t\x12\x11\n\tmore_text\x18\x06 \x01(\t\x12\x0e\n\x06\x63overs\x18\x07 \x03(\t\x12\x18\n\x10\x63over_right_text\x18\x08 \x01(\t\x12@\n\x15top_rcmd_reason_style\x18\t \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\x95\x01\n\rMiddleCoverV3\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\r\n\x05\x64\x65sc1\x18\x02 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x03 \x01(\t\x12<\n\x11\x63over_badge_style\x18\x04 \x01(\x0b\x32!.bilibili.app.card.v1.ReasonStyle\"\xb8\x02\n\x0cLargeCoverV4\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x19\n\x11\x63over_left_text_1\x18\x02 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x04 \x01(\t\x12\x13\n\x0b\x63over_badge\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61n_play\x18\x06 \x01(\x05\x12$\n\x02up\x18\x07 \x01(\x0b\x32\x18.bilibili.app.card.v1.Up\x12\x12\n\nshort_link\x18\x08 \x01(\t\x12\x16\n\x0eshare_subtitle\x18\t \x01(\t\x12\x13\n\x0bplay_number\x18\n \x01(\t\x12\x0c\n\x04\x62vid\x18\x0b \x01(\t\x12\x11\n\tsub_param\x18\x0c \x01(\t\"q\n\x12PopularTopEntrance\x12(\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.card.v1.Base\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".bilibili.app.card.v1.EntranceItem\"\xb3\x01\n\x0c\x45ntranceItem\x12\x0c\n\x04goto\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tmodule_id\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x13\n\x0b\x65ntrance_id\x18\x06 \x01(\x03\x12,\n\x06\x62ubble\x18\x07 \x01(\x0b\x32\x1c.bilibili.app.card.v1.Bubble\x12\x15\n\rentrance_type\x18\x08 \x01(\x05\"@\n\x06\x42ubble\x12\x16\n\x0e\x62ubble_content\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\r\n\x05stime\x18\x03 \x01(\x03\x62\x06proto3')



_SMALLCOVERV5 = DESCRIPTOR.message_types_by_name['SmallCoverV5']
_HOTWORDENTRANCE = DESCRIPTOR.message_types_by_name['HotwordEntrance']
_LARGECOVERV1 = DESCRIPTOR.message_types_by_name['LargeCoverV1']
_THREEITEMALLV2 = DESCRIPTOR.message_types_by_name['ThreeItemAllV2']
_TWOITEMHV1ITEM = DESCRIPTOR.message_types_by_name['TwoItemHV1Item']
_RCMDONEITEM = DESCRIPTOR.message_types_by_name['RcmdOneItem']
_SMALLCOVERRCMDITEM = DESCRIPTOR.message_types_by_name['SmallCoverRcmdItem']
_THREEITEMV1 = DESCRIPTOR.message_types_by_name['ThreeItemV1']
_THREEITEMV1ITEM = DESCRIPTOR.message_types_by_name['ThreeItemV1Item']
_HOTTOPICITEM = DESCRIPTOR.message_types_by_name['HotTopicItem']
_HOTTOPIC = DESCRIPTOR.message_types_by_name['HotTopic']
_DYNAMICHOT = DESCRIPTOR.message_types_by_name['DynamicHot']
_MIDDLECOVERV3 = DESCRIPTOR.message_types_by_name['MiddleCoverV3']
_LARGECOVERV4 = DESCRIPTOR.message_types_by_name['LargeCoverV4']
_POPULARTOPENTRANCE = DESCRIPTOR.message_types_by_name['PopularTopEntrance']
_ENTRANCEITEM = DESCRIPTOR.message_types_by_name['EntranceItem']
_BUBBLE = DESCRIPTOR.message_types_by_name['Bubble']
SmallCoverV5 = _reflection.GeneratedProtocolMessageType('SmallCoverV5', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCOVERV5,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallCoverV5)
  })
_sym_db.RegisterMessage(SmallCoverV5)

HotwordEntrance = _reflection.GeneratedProtocolMessageType('HotwordEntrance', (_message.Message,), {
  'DESCRIPTOR' : _HOTWORDENTRANCE,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.HotwordEntrance)
  })
_sym_db.RegisterMessage(HotwordEntrance)

LargeCoverV1 = _reflection.GeneratedProtocolMessageType('LargeCoverV1', (_message.Message,), {
  'DESCRIPTOR' : _LARGECOVERV1,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.LargeCoverV1)
  })
_sym_db.RegisterMessage(LargeCoverV1)

ThreeItemAllV2 = _reflection.GeneratedProtocolMessageType('ThreeItemAllV2', (_message.Message,), {
  'DESCRIPTOR' : _THREEITEMALLV2,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.ThreeItemAllV2)
  })
_sym_db.RegisterMessage(ThreeItemAllV2)

TwoItemHV1Item = _reflection.GeneratedProtocolMessageType('TwoItemHV1Item', (_message.Message,), {
  'DESCRIPTOR' : _TWOITEMHV1ITEM,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.TwoItemHV1Item)
  })
_sym_db.RegisterMessage(TwoItemHV1Item)

RcmdOneItem = _reflection.GeneratedProtocolMessageType('RcmdOneItem', (_message.Message,), {
  'DESCRIPTOR' : _RCMDONEITEM,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.RcmdOneItem)
  })
_sym_db.RegisterMessage(RcmdOneItem)

SmallCoverRcmdItem = _reflection.GeneratedProtocolMessageType('SmallCoverRcmdItem', (_message.Message,), {
  'DESCRIPTOR' : _SMALLCOVERRCMDITEM,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.SmallCoverRcmdItem)
  })
_sym_db.RegisterMessage(SmallCoverRcmdItem)

ThreeItemV1 = _reflection.GeneratedProtocolMessageType('ThreeItemV1', (_message.Message,), {
  'DESCRIPTOR' : _THREEITEMV1,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.ThreeItemV1)
  })
_sym_db.RegisterMessage(ThreeItemV1)

ThreeItemV1Item = _reflection.GeneratedProtocolMessageType('ThreeItemV1Item', (_message.Message,), {
  'DESCRIPTOR' : _THREEITEMV1ITEM,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.ThreeItemV1Item)
  })
_sym_db.RegisterMessage(ThreeItemV1Item)

HotTopicItem = _reflection.GeneratedProtocolMessageType('HotTopicItem', (_message.Message,), {
  'DESCRIPTOR' : _HOTTOPICITEM,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.HotTopicItem)
  })
_sym_db.RegisterMessage(HotTopicItem)

HotTopic = _reflection.GeneratedProtocolMessageType('HotTopic', (_message.Message,), {
  'DESCRIPTOR' : _HOTTOPIC,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.HotTopic)
  })
_sym_db.RegisterMessage(HotTopic)

DynamicHot = _reflection.GeneratedProtocolMessageType('DynamicHot', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICHOT,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.DynamicHot)
  })
_sym_db.RegisterMessage(DynamicHot)

MiddleCoverV3 = _reflection.GeneratedProtocolMessageType('MiddleCoverV3', (_message.Message,), {
  'DESCRIPTOR' : _MIDDLECOVERV3,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.MiddleCoverV3)
  })
_sym_db.RegisterMessage(MiddleCoverV3)

LargeCoverV4 = _reflection.GeneratedProtocolMessageType('LargeCoverV4', (_message.Message,), {
  'DESCRIPTOR' : _LARGECOVERV4,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.LargeCoverV4)
  })
_sym_db.RegisterMessage(LargeCoverV4)

PopularTopEntrance = _reflection.GeneratedProtocolMessageType('PopularTopEntrance', (_message.Message,), {
  'DESCRIPTOR' : _POPULARTOPENTRANCE,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.PopularTopEntrance)
  })
_sym_db.RegisterMessage(PopularTopEntrance)

EntranceItem = _reflection.GeneratedProtocolMessageType('EntranceItem', (_message.Message,), {
  'DESCRIPTOR' : _ENTRANCEITEM,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.EntranceItem)
  })
_sym_db.RegisterMessage(EntranceItem)

Bubble = _reflection.GeneratedProtocolMessageType('Bubble', (_message.Message,), {
  'DESCRIPTOR' : _BUBBLE,
  '__module__' : 'bilibili.app.card.v1.single_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.card.v1.Bubble)
  })
_sym_db.RegisterMessage(Bubble)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SMALLCOVERV5._serialized_start=95
  _SMALLCOVERV5._serialized_end=580
  _HOTWORDENTRANCE._serialized_start=582
  _HOTWORDENTRANCE._serialized_end=667
  _LARGECOVERV1._serialized_start=670
  _LARGECOVERV1._serialized_end=1467
  _THREEITEMALLV2._serialized_start=1470
  _THREEITEMALLV2._serialized_end=1646
  _TWOITEMHV1ITEM._serialized_start=1649
  _TWOITEMHV1ITEM._serialized_end=1859
  _RCMDONEITEM._serialized_start=1862
  _RCMDONEITEM._serialized_end=2036
  _SMALLCOVERRCMDITEM._serialized_start=2039
  _SMALLCOVERRCMDITEM._serialized_end=2254
  _THREEITEMV1._serialized_start=2257
  _THREEITEMV1._serialized_end=2420
  _THREEITEMV1ITEM._serialized_start=2423
  _THREEITEMV1ITEM._serialized_end=2573
  _HOTTOPICITEM._serialized_start=2575
  _HOTTOPICITEM._serialized_end=2646
  _HOTTOPIC._serialized_start=2648
  _HOTTOPIC._serialized_end=2765
  _DYNAMICHOT._serialized_start=2768
  _DYNAMICHOT._serialized_end=3021
  _MIDDLECOVERV3._serialized_start=3024
  _MIDDLECOVERV3._serialized_end=3173
  _LARGECOVERV4._serialized_start=3176
  _LARGECOVERV4._serialized_end=3488
  _POPULARTOPENTRANCE._serialized_start=3490
  _POPULARTOPENTRANCE._serialized_end=3603
  _ENTRANCEITEM._serialized_start=3606
  _ENTRANCEITEM._serialized_end=3785
  _BUBBLE._serialized_start=3787
  _BUBBLE._serialized_end=3851
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CodeReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CODE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""

    def __init__(self,
        *,
        code: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code",b"code"]) -> None: ...
global___CodeReq = CodeReq

class CodeReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___CodeReply = CodeReply

class ProbeReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    buvid: typing.Text
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        buvid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buvid",b"buvid","mid",b"mid"]) -> None: ...
global___ProbeReq = ProbeReq

class ProbeReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    content: typing.Text
    """"""

    timestamp: builtins.int
    """"""

    def __init__(self,
        *,
        content: typing.Text = ...,
        timestamp: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","timestamp",b"timestamp"]) -> None: ...
global___ProbeReply = ProbeReply

class ProbeStreamReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    sequence: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        sequence: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid","sequence",b"sequence"]) -> None: ...
global___ProbeStreamReq = ProbeStreamReq

class ProbeStreamReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEQUENCE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    sequence: builtins.int
    """"""

    timestamp: builtins.int
    """"""

    content: typing.Text
    """"""

    def __init__(self,
        *,
        sequence: builtins.int = ...,
        timestamp: builtins.int = ...,
        content: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","sequence",b"sequence","timestamp",b"timestamp"]) -> None: ...
global___ProbeStreamReply = ProbeStreamReply

class ProbeSubReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUVID_FIELD_NUMBER: builtins.int
    buvid: builtins.int
    """"""

    def __init__(self,
        *,
        buvid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buvid",b"buvid"]) -> None: ...
global___ProbeSubReq = ProbeSubReq

class ProbeSubReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    message_id: builtins.int
    """"""

    def __init__(self,
        *,
        message_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_id",b"message_id"]) -> None: ...
global___ProbeSubReply = ProbeSubReply



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/cheese/gateway/player/v1/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.playurl.v1 import playurl_pb2 as bilibili_dot_app_dot_playurl_dot_v1_dot_playurl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/cheese/gateway/player/v1/playurl.proto\x12!bilibili.cheese.gateway.player.v1\x1a%bilibili/app/playurl/v1/playurl.proto\"\x95\x02\n\x0bPlayViewReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x0b \x01(\x05\x12<\n\x11prefer_codec_type\x18\x0c \x01(\x0e\x32!.bilibili.app.playurl.v1.CodeType\x12\x12\n\nis_preview\x18\r \x01(\x08\"\xe3\x01\n\nProjectReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x10\n\x08protocol\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x65vice_type\x18\x0c \x01(\x05\x12\x10\n\x08\x66lv_proj\x18\r \x01(\x08\"\x8e\x01\n\rPlayViewReply\x12\x36\n\nvideo_info\x18\x01 \x01(\x0b\x32\".bilibili.app.playurl.v1.VideoInfo\x12\x45\n\tplay_conf\x18\x02 \x01(\x0b\x32\x32.bilibili.cheese.gateway.player.v1.PlayAbilityConf\"\xa5\x05\n\x0fPlayAbilityConf\x12\x1f\n\x17\x62\x61\x63kground_play_disable\x18\x01 \x01(\x08\x12\x14\n\x0c\x66lip_disable\x18\x02 \x01(\x08\x12\x14\n\x0c\x63\x61st_disable\x18\x03 \x01(\x08\x12\x18\n\x10\x66\x65\x65\x64\x62\x61\x63k_disable\x18\x04 \x01(\x08\x12\x18\n\x10subtitle_disable\x18\x05 \x01(\x08\x12\x1d\n\x15playback_rate_disable\x18\x06 \x01(\x08\x12\x17\n\x0ftime_up_disable\x18\x07 \x01(\x08\x12\x1d\n\x15playback_mode_disable\x18\x08 \x01(\x08\x12\x1a\n\x12scale_mode_disable\x18\t \x01(\x08\x12\x14\n\x0clike_disable\x18\n \x01(\x08\x12\x17\n\x0f\x64islike_disable\x18\x0b \x01(\x08\x12\x14\n\x0c\x63oin_disable\x18\x0c \x01(\x08\x12\x14\n\x0c\x65lec_disable\x18\r \x01(\x08\x12\x15\n\rshare_disable\x18\x0e \x01(\x08\x12\x1b\n\x13screen_shot_disable\x18\x0f \x01(\x08\x12\x1b\n\x13lock_screen_disable\x18\x10 \x01(\x08\x12\x19\n\x11recommend_disable\x18\x11 \x01(\x08\x12\x1e\n\x16playback_speed_disable\x18\x12 \x01(\x08\x12\x1a\n\x12\x64\x65\x66inition_disable\x18\x13 \x01(\x08\x12\x1a\n\x12selections_disable\x18\x14 \x01(\x08\x12\x14\n\x0cnext_disable\x18\x15 \x01(\x08\x12\x17\n\x0f\x65\x64it_dm_disable\x18\x16 \x01(\x08\x12\x18\n\x10outer_dm_disable\x18\x19 \x01(\x08\x12\x18\n\x10inner_dm_disable\x18\x1a \x01(\x08\x12\x1c\n\x14small_window_disable\x18\x1b \x01(\x08\"F\n\x0cProjectReply\x12\x36\n\x07project\x18\x01 \x01(\x0b\x32%.bilibili.app.playurl.v1.PlayURLReply2\xe2\x01\n\x07PlayURL\x12l\n\x08PlayView\x12..bilibili.cheese.gateway.player.v1.PlayViewReq\x1a\x30.bilibili.cheese.gateway.player.v1.PlayViewReply\x12i\n\x07Project\x12-.bilibili.cheese.gateway.player.v1.ProjectReq\x1a/.bilibili.cheese.gateway.player.v1.ProjectReplyb\x06proto3')



_PLAYVIEWREQ = DESCRIPTOR.message_types_by_name['PlayViewReq']
_PROJECTREQ = DESCRIPTOR.message_types_by_name['ProjectReq']
_PLAYVIEWREPLY = DESCRIPTOR.message_types_by_name['PlayViewReply']
_PLAYABILITYCONF = DESCRIPTOR.message_types_by_name['PlayAbilityConf']
_PROJECTREPLY = DESCRIPTOR.message_types_by_name['ProjectReply']
PlayViewReq = _reflection.GeneratedProtocolMessageType('PlayViewReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYVIEWREQ,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.PlayViewReq)
  })
_sym_db.RegisterMessage(PlayViewReq)

ProjectReq = _reflection.GeneratedProtocolMessageType('ProjectReq', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREQ,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.ProjectReq)
  })
_sym_db.RegisterMessage(ProjectReq)

PlayViewReply = _reflection.GeneratedProtocolMessageType('PlayViewReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYVIEWREPLY,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.PlayViewReply)
  })
_sym_db.RegisterMessage(PlayViewReply)

PlayAbilityConf = _reflection.GeneratedProtocolMessageType('PlayAbilityConf', (_message.Message,), {
  'DESCRIPTOR' : _PLAYABILITYCONF,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.PlayAbilityConf)
  })
_sym_db.RegisterMessage(PlayAbilityConf)

ProjectReply = _reflection.GeneratedProtocolMessageType('ProjectReply', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREPLY,
  '__module__' : 'bilibili.cheese.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.cheese.gateway.player.v1.ProjectReply)
  })
_sym_db.RegisterMessage(ProjectReply)

_PLAYURL = DESCRIPTOR.services_by_name['PlayURL']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLAYVIEWREQ._serialized_start=126
  _PLAYVIEWREQ._serialized_end=403
  _PROJECTREQ._serialized_start=406
  _PROJECTREQ._serialized_end=633
  _PLAYVIEWREPLY._serialized_start=636
  _PLAYVIEWREPLY._serialized_end=778
  _PLAYABILITYCONF._serialized_start=781
  _PLAYABILITYCONF._serialized_end=1458
  _PROJECTREPLY._serialized_start=1460
  _PROJECTREPLY._serialized_end=1530
  _PLAYURL._serialized_start=1533
  _PLAYURL._serialized_end=1759
# @@protoc_insertion_point(module_scope)
